package at.ac.uibk.gitsearch.service.gitlab_events;

import java.io.IOException;
import java.io.PipedInputStream;
import java.util.Date;
import java.util.UUID;

/**
 * this class holds the log output as a string.
 *
 * @author Micha
 *
 */
public class LogHolder {

    private final PipedInputStream is;
    private final UUID id;

    @SuppressWarnings("PMD.AvoidStringBufferField")
    private final StringBuilder readContent = new StringBuilder();

    private boolean closed = false;
    private boolean error = false;
    private final Date creationDate = new Date();

    protected LogHolder(PipedInputStream is) {
        super();
        this.is = is;
        this.id = UUID.randomUUID();
    }

    protected void readWithoutBlocking() {
        try {
            int maxAvailable = is.available();
            if (maxAvailable > 0) {
                byte[] buffer = new byte[maxAvailable];
                is.read(buffer, 0, maxAvailable);
                readContent.append(new String(buffer));
            }
        } catch (IOException e) {
            GitlabEventService.logger.warn("Cannot read logs");
        }
    }

    public PipedInputStream getIs() {
        return is;
    }

    public UUID getId() {
        return id;
    }

    public StringBuilder getReadContent() {
        synchronized (this) {
            readWithoutBlocking();
            return readContent;
        }
    }

    public void moveForward(int n) {
        synchronized (this) {
            if (n > readContent.length()) {
                throw new IllegalArgumentException(
                    "There are not enough characters (" + readContent.length() + " available) to delete " + n
                );
            }
            readContent.delete(0, n);
        }
    }

    public String readAndDelete() {
        synchronized (this) {
            String result = getReadContent().toString();
            moveForward(result.length());
            return result;
        }
    }

    public boolean isClosed() {
        return closed;
    }

    public boolean isError() {
        return error;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setClosed(boolean closed) {
        this.closed = closed;
    }

    public void setError(boolean error) {
        this.error = error;
    }
}
