package at.ac.uibk.gitsearch.web.rest;

import at.ac.uibk.gitsearch.service.vocabulary.VocabularyService;
import at.ac.uibk.gitsearch.service.vocabulary.VocabularyService.ValidationResultDTO;
import javax.validation.Valid;
import org.codeability.sharing.plugins.api.search.UserProvidedMetadataDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * this resource validates the metadata files.
 *
 * @author Michael Breu
 *
 */
@RestController
@RequestMapping("/api")
public class ValidationCheckerResource {

    @Autowired
    private VocabularyService vocabularyService;

    @Value("${jhipster.clientApp.name}")
    @SuppressWarnings({ "PMD.ImmutableField", "PMD.AvoidDuplicateLiterals", "PMD.UnusedPrivateField" })
    private String applicationName;

    /**
     * GET some file of an exercise.
     *
     * @param filePath the file path
     * @return the ResponseEntity with status 200 (OK) and with body the exercise file, or with status 404 (Not Found)
     */
    @PostMapping("/validateMetaData")
    @SuppressWarnings("PMD.CloseResource")
    public ResponseEntity<ValidationResultDTO> validateMetaData(
        @Valid @RequestBody UserProvidedMetadataDTO metadata,
        @RequestParam(name = "topLevel", defaultValue = "True") Boolean topLevel
    ) {
        return ResponseEntity.ok().body(vocabularyService.validateMetaData(metadata, topLevel));
    }
}
