import { Component, OnInit, OnDestroy, Input } from '@angular/core';
import { encodeURIforExerciseId } from 'app/exercise/service/exercise.service';

import { Person } from 'app/shared/model/person.model';
import { Subscription } from 'rxjs';
import { Account } from 'app/core/auth/account.model';
import { AccountService } from 'app/core/auth/account.service';
import { SearchResultDTO } from 'app/shared/model/search/search-result-dto.model';

@Component({
  selector: 'jhi-exercise-metadata',
  templateUrl: './exercise-metadata.component.html',
  styleUrls: ['./exercise-metadata.component.scss'],
})
export class ExerciseMetadataComponent implements OnInit, OnDestroy {
  @Input() exercise: SearchResultDTO | undefined;
  account: Account | null = null;
  authSubscription?: Subscription;

  encodeURIforExerciseId = encodeURIforExerciseId; // just make it available for template

  constructor(private accountService: AccountService) {}

  ngOnInit(): void {
    this.authSubscription = this.accountService.getAuthenticationState().subscribe(account => (this.account = account));
  }

  public isAuthenticated(): boolean {
    return this.accountService.isAuthenticated();
  }

  public getPersonName(person: Person): string {
    return person.name;
  }

  public getPersonDetails(person: Person): string {
    return person.name + ', ' + person.affiliation;
  }

  public getPersonDetailsWithEmail(person: Person): string {
    return "<a class='text-dark' href='mailto:" + person.email + "'>" + person.name + ', ' + person.affiliation + '</a>';
  }

  ngOnDestroy(): void {
    if (this.authSubscription) {
      this.authSubscription.unsubscribe();
    }
  }
}
